# CognitiveGeo

![](https://github.com/geopyteam/cognitivegeo/blob/master/logo.png?raw=true)

[CognitiveGeo] is a Python GUI for geoscientific data analysis (i.e., seismic).

### Dependency

[CognitiveGeo] uses a number of open source projects to work properly:

* [PyQt5] - GUIs
* [Vispy] - Visualizations

### Installation

* pip install --upgrade cognitivegeo

### Run

* import cognitivegeo as cgeo
* cgeo.gui.start()

### Developers

[CognitiveGeo] is developed by [GeoPy Team].

### Support

[Contact us] if you have any problem with using [CognitiveGeo] and/or want to be a developer.

### License
GNU Affero General Public License v3 or later (AGPLv3+)

[//]: # (These are reference links used in the body of this note and get stripped out when the markdown processor does its job. There is no need to format nicely because it shouldn't be seen. Thanks SO - http://stackoverflow.com/questions/4823468/store-comments-in-markdown-syntax)


   [CognitiveGeo]: <https://geopyteam.wixsite.com/cognitivegeo>
   [PyQt5]: <https://pypi.org/project/PyQt5/>
   [vispy]: <https://pypi.org/project/vispy/>
   [Geopy Team]: <https://www.linkedin.com/in/geopy-team-182b27185/>
   [Contact us]: <https://geopyteam.wixsite.com/cognitivegeo/support>
